[−][src]Struct onedrive_api::query_option::CollectionOption
Option for the request to a collection of resource objects.
Methods
impl<Field: ResourceField> CollectionOption<Field>[src]
pub fn new() -> Self[src]
Create an empty (default) option.
pub fn select(self, fields: &[Field]) -> Self[src]
pub fn expand(self, field: Field, select_children: Option<&[&str]>) -> Self[src]
pub fn order_by(self, field: Field, order: Order) -> Self[src]
Specify the sort order of the items responsed.
Note
If called more than once, only the last call make sense.
See also
pub fn page_size(self, size: usize) -> Self[src]
Specify the number of items per page.
Note
If called more than once, only the last call make sense.
See also
pub fn get_count(self, get_count: bool) -> Self[src]