pub struct Error { /* private fields */ }Expand description
Error of API request
Implementations
Sourceimpl Error
impl Error
Sourcepub fn error_response(&self) -> Option<&ErrorResponse>
pub fn error_response(&self) -> Option<&ErrorResponse>
Get the error response from API if caused by error status code.
Sourcepub fn oauth2_error_response(&self) -> Option<&OAuth2ErrorResponse>
pub fn oauth2_error_response(&self) -> Option<&OAuth2ErrorResponse>
Get the OAuth2 error response from API if caused by OAuth2 error response.
Sourcepub fn status_code(&self) -> Option<StatusCode>
pub fn status_code(&self) -> Option<StatusCode>
Get the HTTP status code if caused by error status code.
Sourcepub fn retry_after(&self) -> Option<Duration>
pub fn retry_after(&self) -> Option<Duration>
Get the retry delay hint on rate limited (HTTP 429) or server unavailability, if any.
This is parsed from response header Retry-After.
See: https://learn.microsoft.com/en-us/graph/throttling